@@ -32,8 +32,10 @@ is the manifold on which the solution must live. A common form for this is the
 two-point `BVProblem` where the manifold defines the solution at two points:
 
 ```math
-u(t_0) = a
-u(t_f) = b
+\begin{align*}
+u(t_0) &= a, \\
+u(t_f) &= b
+\end{align*}
 ```
 
 ## Problem Type
@@ -72,17 +74,18 @@ Note that all features of the `ODESolution` are present in this form.
 In both cases, the size of the residual matches the size of the initial condition.
 
 If the bvp is a TwoPointBVProblem then `bc` must be a Tuple `(bca, bcb)` and each of them
-must define either of the following functions:
+must define either of the following sets of functions:
 
 ```julia
-begin
-    bca!(resid_a, u_a, p)
-    bcb!(resid_b, u_b, p)
-end
-begin
-    resid_a = bca(u_a, p)
-    resid_b = bcb(u_b, p)
-end
+bca!(resid_a, u_a, p)
+bcb!(resid_b, u_b, p)
+```
+
+or
+
+```julia
+resid_a = bca(u_a, p)
+resid_b = bcb(u_b, p)
 ```
 
 where `resid_a` and `resid_b` are the residuals at the two endpoints, `u_a` and `u_b` are
@@ -270,21 +273,23 @@ To define a second order BVP Problem, you simply need to give the function ``f``
 condition ``u_0`` which define an ODE:
 
 ```math
-\frac{ddu}{dt} = f(du,u,p,t)
+u'' = \frac{d^2 u}{dt^2} = f(u', u, p, t)
 ```
 
 along with an implicit function `bc` which defines the residual equation, where
 
 ```math
-bc(du,u,p,t) = 0
+bc(u', u, p, t) = 0
 ```
 
 is the manifold on which the solution must live. A common form for this is the
 two-point `SecondOrderBVProblem` where the manifold defines the solution at two points:
 
 ```math
-g(u(t_0),u'(t_0)) = 0
-g(u(t_f),u'(t_f)) = 0
+\begin{align*}
+g(u(t_0), u'(t_0)) &= 0 \\
+g(u(t_f), u'(t_f)) &= 0
+\end{align*}
 ```
 
 ## Problem Type
@@ -323,17 +328,18 @@ Note that all features of the `ODESolution` are present in this form.
 In both cases, the size of the residual matches the size of the initial condition.
 
 If the bvp is a `TwoPointSecondOrderBVProblem` then `bc` must be a Tuple `(bca, bcb)` and each of them
-must define either of the following functions:
+must define either of the following sets of functions:
 
 ```julia
-begin
-    bca!(resid_a, du_a, u_a, p)
-    bcb!(resid_b, du_b, u_b, p)
-end
-begin
-    resid_a = bca(du_a, u_a, p)
-    resid_b = bcb(du_b, u_b, p)
-end
+bca!(resid_a, du_a, u_a, p)
+bcb!(resid_b, du_b, u_b, p)
+```
+
+or
+
+```julia
+resid_a = bca(du_a, u_a, p)
+resid_b = bcb(du_b, u_b, p)
 ```
 
 where `resid_a` and `resid_b` are the residuals at the two endpoints, `u_a` and `u_b` are
