@@ -150,28 +150,36 @@ For specifying Jacobians and mass matrices, see the
 * `f`: The function in the problem.
 * `u0`: The initial guess for the root.
 * `p`: The parameters for the problem. Defaults to `NullParameters`.
+* `lb`: Lower bounds for the solution. Defaults to `nothing`.
+* `ub`: Upper bounds for the solution. Defaults to `nothing`.
 * `kwargs`: The keyword arguments passed on to the solvers.
 """
-mutable struct NonlinearProblem{uType, isinplace, P, F, K, PT} <:
+mutable struct NonlinearProblem{uType, isinplace, P, F, K, PT, LB, UB} <:
                AbstractNonlinearProblem{uType, isinplace}
     f::F
     u0::uType
     p::P
     problem_type::PT
+    lb::LB
+    ub::UB
     kwargs::K
     @add_kwonly function NonlinearProblem{iip}(f::AbstractNonlinearFunction{iip}, u0,
             p = NullParameters(),
             problem_type = StandardNonlinearProblem();
+            lb = nothing,
+            ub = nothing,
             kwargs...) where {iip}
         if haskey(kwargs, :p)
             error("`p` specified as a keyword argument `p = $(kwargs[:p])` to `NonlinearProblem`. This is not supported.")
         end
         warn_paramtype(p)
         new{typeof(u0), iip, typeof(p), typeof(f),
-            typeof(kwargs), typeof(problem_type)}(f,
+            typeof(kwargs), typeof(problem_type), typeof(lb), typeof(ub)}(f,
             u0,
             p,
             problem_type,
+            lb,
+            ub,
             kwargs)
     end
 
@@ -204,7 +212,7 @@ end
 """
 $(SIGNATURES)
 
-Define a NonlinearProblem problem from SteadyStateProblem
+Define a `NonlinearProblem` problem from `SteadyStateProblem`
 """
 function NonlinearProblem(prob::AbstractNonlinearProblem)
     NonlinearProblem{isinplace(prob)}(prob.f, prob.u0, prob.p)
@@ -223,13 +231,13 @@ function NonlinearProblem(f::AbstractODEFunction, u0, p = NullParameters(); kwar
 end
 
 function ConstructionBase.constructorof(::Type{P}) where {P <: NonlinearProblem}
-    function ctor(f, u0, p, pt, kw)
+    function ctor(f, u0, p, pt, lb, ub, kw)
         if f isa AbstractNonlinearFunction
             iip = isinplace(f)
         else
             iip = isinplace(f, 4)
         end
-        return NonlinearProblem{iip}(f, u0, p, pt; kw...)
+        return NonlinearProblem{iip}(f, u0, p, pt; lb, ub, kw...)
     end
 end
 
@@ -238,7 +246,7 @@ $(SIGNATURES)
 
 Define a nonlinear problem from a standard ODE problem. Note that
 this is interpreted in the form of the steady state problem, i.e.
-find the ODE's solution at time ``t = \\infty``
+find the ODE's solution at time ``t = ∞``
 """
 function NonlinearProblem(prob::AbstractODEProblem)
     NonlinearProblem{isinplace(prob)}(prob.f, prob.u0, prob.p; prob.kwargs...)
@@ -263,7 +271,7 @@ To define a Nonlinear Problem, you simply need to give the function ``f`` which
 nonlinear system:
 
 ```math
-\underset{x}{\min} \| f(x, p) \|
+\min_x \| f(x, p) \|
 ```
 
 and an initial guess ``u_0`` for the minimization problem. ``f`` should be specified as
@@ -296,21 +304,29 @@ For specifying Jacobians and mass matrices, see the
 * `f`: The function in the problem.
 * `u0`: The initial guess for the solution.
 * `p`: The parameters for the problem. Defaults to `NullParameters`.
+* `lb`: Lower bounds for the solution. Defaults to `nothing`.
+* `ub`: Upper bounds for the solution. Defaults to `nothing`.
 * `kwargs`: The keyword arguments passed on to the solvers.
 """
-struct NonlinearLeastSquaresProblem{uType, isinplace, P, F, K} <:
+struct NonlinearLeastSquaresProblem{uType, isinplace, P, F, K, LB, UB} <:
        AbstractNonlinearProblem{uType, isinplace}
     f::F
     u0::uType
     p::P
+    lb::LB
+    ub::UB
     kwargs::K
 
     @add_kwonly function NonlinearLeastSquaresProblem{iip}(
             f::AbstractNonlinearFunction{
                 iip}, u0,
-            p = NullParameters(); kwargs...) where {iip}
+            p = NullParameters();
+            lb = nothing,
+            ub = nothing,
+            kwargs...) where {iip}
         warn_paramtype(p)
-        return new{typeof(u0), iip, typeof(p), typeof(f), typeof(kwargs)}(f, u0, p, kwargs)
+        return new{typeof(u0), iip, typeof(p), typeof(f), typeof(kwargs),
+                   typeof(lb), typeof(ub)}(f, u0, p, lb, ub, kwargs)
     end
 
     function NonlinearLeastSquaresProblem{iip}(f, u0, p = NullParameters()) where {iip}
@@ -334,13 +350,13 @@ function NonlinearLeastSquaresProblem(f, u0, p = NullParameters(); kwargs...)
 end
 
 function ConstructionBase.constructorof(::Type{P}) where {P <: NonlinearLeastSquaresProblem}
-    function ctor(f, u0, p, kw)
+    function ctor(f, u0, p, lb, ub, kw)
         if f isa AbstractNonlinearFunction
             iip = isinplace(f)
         else
             iip = isinplace(f, 4)
         end
-        return NonlinearLeastSquaresProblem{iip}(f, u0, p; kw...)
+        return NonlinearLeastSquaresProblem{iip}(f, u0, p; lb, ub, kw...)
     end
 end
 
@@ -362,11 +378,13 @@ form. In this form, the nonlinear problem can be decomposed into a system
 of nonlinear systems. 
 
 ```math
-f_1(u_1,p) = 0
-f_2(u_2,u_1,p) = 0
-f_3(u_3,u_2,u_1,p) = 0
-\vdots
-f_n(u_n,\ldots,u_3,u_2,u_1,p) = 0
+\begin{align*}
+f_1(u_1,p) &= 0 \\
+f_2(u_2,u_1,p) &= 0 \\
+f_3(u_3,u_2,u_1,p) &= 0 \\
+& \vdots \\
+f_n(u_n,\ldots,u_3,u_2,u_1,p) &= 0
+\end{align*}
 ```
 
 Splitting the system in this form can have multiple advantages, including:
@@ -379,20 +397,18 @@ to solve in order solve the system in the optimized split form.
 
 ## Representation
 
-The representation of the SCCNonlinearProblem is via an ordered collection
+The representation of the `SCCNonlinearProblem` is via an ordered collection
 of `NonlinearProblem`s, `probs`, with an attached explicit function for pre-processing
 a cache. This can be interpreted as follows:
 
 ```math
-p_1 = g_1(u,p)
-f_1(u_1,p_1) = 0
-p_2 = g_2(u,p)
-f_2(u_2,u_1,p_2) = 0
-p_3 = g_3(u,p)
-f_3(u_3,u_2,u_1,p_3) = 0
-\vdots
-p_n = g_n(u,p)
-f_n(u_n,\ldots,u_3,u_2,u_1,p_n) = 0
+\begin{align*}
+p_1 &= g_1(u,p) & f_1(u_1,p_1)         &= 0 \\
+p_2 &= g_2(u,p) & f_2(u_2,u_1,p_2)     &= 0 \\
+p_3 &= g_3(u,p) & f_3(u_3,u_2,u_1,p_3) &= 0 \\
+& \vdots \\
+p_n &= g_n(u,p) & f_n(u_n,\ldots,u_3,u_2,u_1,p_n) &= 0 \\
+\end{align*}
 ```
 
 where ``g_i`` is `explicitfuns![i]`. In a computational sense, `explictfuns!`
@@ -400,11 +416,11 @@ is instead a mutating function `explictfuns![i](prob.probs[i],sols)` which
 updates the values of prob.probs[i] using the previous solutions `sols[i-1]`
 and below.
 
-!!! warn
+!!! warning
     For the purposes of differentiation, it's assumed that `explictfuns!` does
     not modify tunable parameters!
 
-!!! warn
+!!! warning
     While `explictfuns![i]` could in theory use `sols[i+1]` in its computation,
     these values will not be updated. It is thus the contract of the interface
     to not use those values except for as caches to be overridden.
@@ -420,14 +436,14 @@ For the following nonlinear problem:
 
 ```julia
 function f(du,u,p)
-	du[1] = cos(u[2]) - u[1]
-	du[2] = sin(u[1] + u[2]) + u[2]
-	du[3] = 2u[4] + u[3] + 1.0
-	du[4] = u[5]^2 + u[4]
-	du[5] = u[3]^2 + u[5]
-	du[6] = u[1] + u[2] + u[3] + u[4] + u[5]    + 2.0u[6] + 2.5u[7] + 1.5u[8]
-	du[7] = u[1] + u[2] + u[3] + 2.0u[4] + u[5] + 4.0u[6] - 1.5u[7] + 1.5u[8]
-	du[8] = u[1] + 2.0u[2] + 3.0u[3] + 5.0u[4] + 6.0u[5] + u[6] - u[7] - u[8]
+    du[1] = cos(u[2]) - u[1]
+    du[2] = sin(u[1] + u[2]) + u[2]
+    du[3] = 2u[4] + u[3] + 1.0
+    du[4] = u[5]^2 + u[4]
+    du[5] = u[3]^2 + u[5]
+    du[6] = u[1] + u[2] + u[3] + u[4] + u[5]    + 2.0u[6] + 2.5u[7] + 1.5u[8]
+    du[7] = u[1] + u[2] + u[3] + 2.0u[4] + u[5] + 4.0u[6] - 1.5u[7] + 1.5u[8]
+    du[8] = u[1] + 2.0u[2] + 3.0u[3] + 5.0u[4] + 6.0u[5] + u[6] - u[7] - u[8]
 end
 prob = NonlinearProblem(f, zeros(8))
 sol = solve(prob)
@@ -439,38 +455,40 @@ The split SCC form is:
 cache = zeros(3)
 
 function f1(du,u,cache)
-	du[1] = cos(u[2]) - u[1]
-	du[2] = sin(u[1] + u[2]) + u[2]
+    du[1] = cos(u[2]) - u[1]
+    du[2] = sin(u[1] + u[2]) + u[2]
 end
 explicitfun1(cache,sols) = nothing
 prob1 = NonlinearProblem(NonlinearFunction{true, SciMLBase.NoSpecialize}(f1), zeros(2), cache)
 sol1 = solve(prob1, NewtonRaphson())
 
 function f2(du,u,cache)
-	du[1] = 2u[2] + u[1] + 1.0
-	du[2] = u[3]^2 + u[2]
-	du[3] = u[1]^2 + u[3]
+    du[1] = 2u[2] + u[1] + 1.0
+    du[2] = u[3]^2 + u[2]
+    du[3] = u[1]^2 + u[3]
 end
 explicitfun2(cache,sols) = nothing
 prob2 = NonlinearProblem(NonlinearFunction{true, SciMLBase.NoSpecialize}(f2), zeros(3), cache)
 sol2 = solve(prob2, NewtonRaphson())
 
 function f3(du,u,cache)
-	du[1] = cache[1] + 2.0u[1] + 2.5u[2] + 1.5u[3]
-	du[2] = cache[2] + 4.0u[1] - 1.5u[2] + 1.5u[3]
-	du[3] = cache[3] + + u[1] - u[2] - u[3]
+    du[1] = cache[1] + 2.0u[1] + 2.5u[2] + 1.5u[3]
+    du[2] = cache[2] + 4.0u[1] - 1.5u[2] + 1.5u[3]
+    du[3] = cache[3] + + u[1] - u[2] - u[3]
 end
 prob3 = NonlinearProblem(NonlinearFunction{true, SciMLBase.NoSpecialize}(f3), zeros(3), cache)
 function explicitfun3(cache,sols)
-	cache[1] = sols[1][1] + sols[1][2] + sols[2][1] + sols[2][2] + sols[2][3]
-	cache[2] = sols[1][1] + sols[1][2] + sols[2][1] + 2.0sols[2][2] + sols[2][3]
-	cache[3] = sols[1][1] + 2.0sols[1][2] + 3.0sols[2][1] + 5.0sols[2][2] + 6.0sols[2][3]
+    cache[1] = sols[1][1] + sols[1][2] + sols[2][1] + sols[2][2] + sols[2][3]
+    cache[2] = sols[1][1] + sols[1][2] + sols[2][1] + 2.0sols[2][2] + sols[2][3]
+    cache[3] = sols[1][1] + 2.0sols[1][2] + 3.0sols[2][1] + 5.0sols[2][2] + 6.0sols[2][3]
 end
 explicitfun3(cache,[sol1,sol2])
 sol3 = solve(prob3, NewtonRaphson())
 manualscc = [sol1; sol2; sol3]
 
-sccprob = SciMLBase.SCCNonlinearProblem([prob1,prob2,prob3], SciMLBase.Void{Any}.([explicitfun1,explicitfun2,explicitfun3]))
+sccprob = SciMLBase.SCCNonlinearProblem(
+    [prob1,prob2,prob3],
+    SciMLBase.Void{Any}.([explicitfun1,explicitfun2,explicitfun3]))
 ```
 
 Note that this example aliases the parameters together for a memory-reduced representation.
@@ -642,7 +660,7 @@ function ImmutableNonlinearProblem(f, u0, p = NullParameters(); kwargs...)
 end
 
 """
-Define a ImmutableNonlinearProblem problem from SteadyStateProblem.
+Define a `ImmutableNonlinearProblem` problem from `SteadyStateProblem`.
 """
 function ImmutableNonlinearProblem(prob::AbstractNonlinearProblem)
     return ImmutableNonlinearProblem{SciMLBase.isinplace(prob)}(prob.f, prob.u0, prob.p)
